# Translation of Source Code for DocFX Websites

This tool translates the source code in Markdown and Yaml for DocFX websites, preserving markup sintax.

Powered by [Yandex.Translate](http://translate.yandex.com)